@@ -26,6 +26,7 @@
 #include <kdebug.h>
 #include <kpopupmenu.h>
 #include <kaboutdata.h>
+#include <ktempfile.h>
 
 #include <qfile.h>
 
@@ -40,6 +41,7 @@ KAboutData *ArkPart::createAboutData()
                                        I18N_NOOP("Ark KParts Component"),
                                        KAboutData::License_GPL,
                                        "(c) 1997-2001, The Various Ark Developers");
+	 
     about->addAuthor("Robert Palmbos",0, "palm9744@kettering.edu");
     about->addAuthor("Francois-Xavier Duranceau",0, "duranceau@kde.org");
     about->addAuthor("Corel Corporation (author: Emily Ezust)",0,
@@ -48,6 +50,8 @@ KAboutData *ArkPart::createAboutData()
                      "michaelj@corel.com");
     about->addAuthor("Jian Huang");
     about->addAuthor( "Roberto Teixeira", 0, "maragato@kde.org" );
+    about->addAuthor("Helio Chissini de Castro",0, "helio@conectiva.com.br");
+    about->addAuthor("Georg Robbers",0, "georg@pacaterie.u-psud.fr");
 
     return about;
 }
@@ -77,6 +81,7 @@ ArkPart::ArkPart( QWidget *parentWidget, const char *widgetName, QObject *parent
     else
     {
         setArchivePopupEnabled( false );
+        disconnect( awidget, SIGNAL( signalFilePopup( const QPoint& ) ), this, SLOT( slotFilePopup( const QPoint& ) ) );
         setXMLFile( "ark_part_readonly.rc" );
     }
     setReadWrite( readWrite );
@@ -269,5 +274,10 @@ void ArkPart::slotSaveProperties()
     kdDebug(1601) << "-saveProperties (exit)" << endl;
 }
 
+bool ArkPart::openURL( const KURL &url )
+{
+    awidget->setRealURL( url );
+    return KParts::ReadWritePart::openURL( url );
+}
 
 #include "ark_part.moc"
