@@ -1,5 +1,5 @@
 /*
-    $Id: kcalc_core.cpp,v 1.59 2002/09/23 21:25:21 waba Exp $
+    $Id: kcalc_core.cpp,v 1.59.2.1 2003/02/15 20:52:55 staikos Exp $
 
     kCalculator, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -1676,7 +1676,7 @@ void QtCalculator::UpdateDisplay()
 							kcalcdefaults.precision + 1,
 							DISPLAY_AMOUNT);
 			} else {
-				str_size = snprintf(display_str, DSP_SIZE, PRINT_LONG, DISPLAY_AMOUNT);
+				str_size = snprintf(display_str, DSP_SIZE, PRINT_LONG_BIG, kcalcdefaults.precision, DISPLAY_AMOUNT);
 			}
 
 			if (input_count > 0 && !strpbrk(display_str,"e") &&
