@@ -1,6 +1,6 @@
   /*
 
-    $Id: kedit.cpp,v 1.165 2002/09/30 14:37:08 dnaber Exp $
+    $Id: kedit.cpp,v 1.165.2.1 2003/01/31 03:01:55 mueller Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -1110,7 +1110,13 @@ int TopLevel::openFile( const QString& _filename, int _mode, const QString &enco
 {
   QFileInfo info(_filename);
 
-  if(!info.exists())
+  if(info.isDir())
+  {
+     KMessageBox::sorry(this, i18n("You have specified a directory"));
+     return KEDIT_RETRY;
+  }
+
+  if(!info.exists() || !info.isFile())
   {
      if ((_mode & OPEN_NEW) != 0)
         return KEDIT_OK;
@@ -1118,12 +1124,6 @@ int TopLevel::openFile( const QString& _filename, int _mode, const QString &enco
      return KEDIT_RETRY;
   }
 
-  if(info.isDir())
-  {
-     KMessageBox::sorry(this, i18n("You have specified a directory"));
-     return KEDIT_RETRY;
-  }
-
   QFile file(_filename);
 
   if(!file.open(IO_ReadOnly))
